pub struct RenderContext { /* private fields */ }Expand description
An interface used for creating command buffers for rendering.
Implementations
Sourceimpl RenderContext
impl RenderContext
Sourcepub fn new<'a>(instance: &Instance<'a>) -> Self
pub fn new<'a>(instance: &Instance<'a>) -> Self
Creates a new RenderContext.
Arguments
instance- the Instance to use for rendering. Borrowed for the duration of the function execution.
Returns
The created RenderContext.
Sourcepub fn create_render_pass_raw(
&mut self,
desc: &RenderPassDescriptor<'_>,
) -> RenderPass<'_>
pub fn create_render_pass_raw( &mut self, desc: &RenderPassDescriptor<'_>, ) -> RenderPass<'_>
Creates a wgpu::RenderPass from a raw wgpu::RenderPassDescriptor. Should generally only be used internally.
Arguments
desc- the wgpu::RenderPassDescriptor to use when creating the wgpu::RenderPass.
Returns
The wgpu::RenderPass matching the argument.
Sourcepub fn clear(&mut self, surf_view: &TextureView, color: Color) -> RenderPass<'_>
pub fn clear(&mut self, surf_view: &TextureView, color: Color) -> RenderPass<'_>
Creates a wgpu::RenderPass which starts by clearing the input texture to a color. Should generally only be used internally.
Arguments
surf_view- the wgpu::TextureView to clear.color- the wgpu::Color to clear the texture to.
Returns
The wgpu::RenderPass, ready for rendering, starting with a clear op.
Sourcepub fn to_command_buffer(self) -> CommandBuffer
pub fn to_command_buffer(self) -> CommandBuffer
Finishes rendering and creates a command buffer.
This method consumes self.
This should generally only be used internally.
Returns
The wgpu::CommandBuffer which may be submit to the GPU for rendering.